@@ -10,17 +10,18 @@
 #
 
 from __future__ import print_function
-import traceback
+
 import sys
+import traceback
 
 from eccodes import *
 
-INPUT = '../../data/tigge_pf_ecmwf.grib2'
+INPUT = "../../data/tigge_pf_ecmwf.grib2"
 VERBOSE = 1  # verbose error reporting
 
 
 def example():
-    f = open(INPUT, 'rb')
+    f = open(INPUT, "rb")
 
     mcount = codes_count_in_file(f)
     gid_list = [codes_grib_new_from_file(f) for i in range(mcount)]
@@ -28,14 +29,14 @@ def example():
     f.close()
 
     keys = [
-        'Ni',
-        'Nj',
-        'latitudeOfFirstGridPointInDegrees',
-        'longitudeOfFirstGridPointInDegrees',
-        'latitudeOfLastGridPointInDegrees',
-        'longitudeOfLastGridPointInDegrees',
-        'jDirectionIncrementInDegrees',
-        'iDirectionIncrementInDegrees',
+        "Ni",
+        "Nj",
+        "latitudeOfFirstGridPointInDegrees",
+        "longitudeOfFirstGridPointInDegrees",
+        "latitudeOfLastGridPointInDegrees",
+        "longitudeOfLastGridPointInDegrees",
+        "jDirectionIncrementInDegrees",
+        "iDirectionIncrementInDegrees",
     ]
 
     for i in range(mcount):
@@ -44,16 +45,19 @@ def example():
         print("processing message number", i + 1)
 
         for key in keys:
-            print('%s=%g' % (key, codes_get(gid, key)))
+            print("%s=%g" % (key, codes_get(gid, key)))
 
-        print('There are %d, average is %g, min is %g, max is %g' % (
-            codes_get_size(gid, 'values'),
-            codes_get(gid, 'average'),
-            codes_get(gid, 'min'),
-            codes_get(gid, 'max')
-        ))
+        print(
+            "There are %d, average is %g, min is %g, max is %g"
+            % (
+                codes_get_size(gid, "values"),
+                codes_get(gid, "average"),
+                codes_get(gid, "min"),
+                codes_get(gid, "max"),
+            )
+        )
 
-        print('-' * 100)
+        print("-" * 100)
 
         codes_release(gid)
 
@@ -65,7 +69,7 @@ def main():
         if VERBOSE:
             traceback.print_exc(file=sys.stderr)
         else:
-            sys.stderr.write(err.msg + '\n')
+            sys.stderr.write(err.msg + "\n")
 
         return 1
 
