@@ -41,16 +41,15 @@ or edit "action.class" and rerun ./make_class.pl
 
 */
 
-static void init_class(grib_action_class*);
-static void dump(grib_action* d, FILE*, int);
-static void destroy(grib_context*, grib_action*);
+static void init_class      (grib_action_class*);
+static void dump            (grib_action* d, FILE*,int);
+static void destroy         (grib_context*,grib_action*);
 
 
-typedef struct grib_action_concept
-{
-    grib_action act;
+typedef struct grib_action_concept {
+    grib_action          act;  
     /* Members defined in gen */
-    long len;
+    long            len;
     grib_arguments* params;
     /* Members defined in concept */
     grib_concept_value* concept;
@@ -63,33 +62,33 @@ typedef struct grib_action_concept
 extern grib_action_class* grib_action_class_gen;
 
 static grib_action_class _grib_action_class_concept = {
-    &grib_action_class_gen,      /* super                     */
-    "action_class_concept",      /* name                      */
-    sizeof(grib_action_concept), /* size                      */
-    0,                           /* inited */
-    &init_class,                 /* init_class */
-    0,                           /* init                      */
-    &destroy,                    /* destroy */
+    &grib_action_class_gen,                              /* super                     */
+    "action_class_concept",                              /* name                      */
+    sizeof(grib_action_concept),            /* size                      */
+    0,                                   /* inited */
+    &init_class,                         /* init_class */
+    0,                               /* init                      */
+    &destroy,                            /* destroy */
 
-    &dump, /* dump                      */
-    0,     /* xref                      */
+    &dump,                               /* dump                      */
+    0,                               /* xref                      */
 
-    0, /* create_accessor*/
+    0,             /* create_accessor*/
 
-    0, /* notify_change */
-    0, /* reparse */
-    0, /* execute */
+    0,                            /* notify_change */
+    0,                            /* reparse */
+    0,                            /* execute */
 };
 
 grib_action_class* grib_action_class_concept = &_grib_action_class_concept;
 
 static void init_class(grib_action_class* c)
 {
-    c->xref            = (*(c->super))->xref;
-    c->create_accessor = (*(c->super))->create_accessor;
-    c->notify_change   = (*(c->super))->notify_change;
-    c->reparse         = (*(c->super))->reparse;
-    c->execute         = (*(c->super))->execute;
+    c->xref    =    (*(c->super))->xref;
+    c->create_accessor    =    (*(c->super))->create_accessor;
+    c->notify_change    =    (*(c->super))->notify_change;
+    c->reparse    =    (*(c->super))->reparse;
+    c->execute    =    (*(c->super))->execute;
 }
 /* END_CLASS_IMP */
 
@@ -208,8 +207,9 @@ static void destroy(grib_context* context, grib_action* act)
     grib_action_concept* self = (grib_action_concept*)act;
 
     grib_concept_value* v = self->concept;
-    if (v)
-        grib_trie_delete(v->index);
+    if (v) {
+        grib_trie_delete_container(v->index);
+    }
     while (v) {
         grib_concept_value* n = v->next;
         grib_concept_value_delete(context, v);
