@@ -133,7 +133,7 @@ typedef struct grib_key_value_list codes_key_value_list;
 */
 typedef struct grib_handle codes_handle;
 
-/*! GRIB multi field handle,   structure used to build multi fields messages.
+/*! GRIB multi-field handle, structure used to build multi-field messages.
     \ingroup codes_handle
     \struct codes_multi_handle
  */
@@ -156,7 +156,6 @@ typedef struct grib_iterator codes_iterator;
     \struct codes_nearest
 */
 typedef struct grib_nearest codes_nearest;
-typedef struct grib_box codes_box;
 typedef struct grib_points codes_points;
 
 /*! Codes keys iterator. Iterator over keys.
@@ -181,13 +180,13 @@ typedef struct grib_util_packing_spec codes_util_packing_spec;
 typedef struct grib_util_grid_spec codes_util_grid_spec;
 
 
-codes_fieldset* codes_fieldset_new_from_files(codes_context* c, char* filenames[], int nfiles, char** keys, int nkeys, const char* where_string, const char* order_by_string, int* err);
+codes_fieldset* codes_fieldset_new_from_files(codes_context* c, const char* filenames[], int nfiles, const char** keys, int nkeys, const char* where_string, const char* order_by_string, int* err);
 
 void codes_fieldset_delete(codes_fieldset* set);
 void codes_fieldset_rewind(codes_fieldset* set);
 int codes_fieldset_apply_order_by(codes_fieldset* set, const char* order_by_string);
 codes_handle* codes_fieldset_next_handle(codes_fieldset* set, int* err);
-int codes_fieldset_count(codes_fieldset* set);
+int codes_fieldset_count(const codes_fieldset* set);
 int codes_values_check(codes_handle* h, codes_values* values, int count);
 
 /*! \defgroup codes_index The indexing feature
@@ -202,7 +201,7 @@ The codes_index is the structure giving indexed access to messages in a file.
 typedef struct grib_index codes_index;
 
 /**
- *  Create a new index form a file. The file is indexed with the keys in argument.
+ *  Create a new index from a file. The file is indexed with the keys in argument.
  *
  * @param c           : context  (NULL for default context)
  * @param filename    : name of the file of messages to be indexed
@@ -312,7 +311,7 @@ int codes_index_select_long(codes_index* index, const char* key, long value);
 int codes_index_select_double(codes_index* index, const char* key, double value);
 
 /**
- *  Select the message subset with key==value. The value is a string. The key must have been created with string type or have string as native type if the type was not explicitly defined in the index creation.
+ * Select the message subset with key==value. The value is a string. The key must have been created with string type or have string as native type if the type was not explicitly defined in the index creation.
  *
  * @param index       : an index created from a file.
  *     The index must have been created with the key in argument.
@@ -323,13 +322,13 @@ int codes_index_select_double(codes_index* index, const char* key, double value)
 int codes_index_select_string(codes_index* index, const char* key, const char* value);
 
 /**
- *  Create a new handle from an index after having selected the key values.
- *  All the keys belonging to the index must be selected before calling this function. Successive calls to this function will return all the handles compatible with the constraints defined selecting the values of the index keys.
+ * Create a new handle from an index after having selected the key values.
+ * All the keys belonging to the index must be selected before calling this function. Successive calls to this function will return all the handles compatible with the constraints defined selecting the values of the index keys.
  * When no more handles are available from the index a NULL pointer is returned and the err variable is set to CODES_END_OF_INDEX.
  *
  * @param index       : an index created from a file.
- * @param err         :  0 if OK, integer value on error. CODES_END_OF_INDEX when no more handles are contained in the index.
- * @return            grib handle.
+ * @param err         : 0 if OK, integer value on error. CODES_END_OF_INDEX when no more handles are contained in the index.
+ * @return            GRIB handle.
  */
 codes_handle* codes_handle_new_from_index(codes_index* index, int* err);
 
@@ -435,7 +434,7 @@ codes_handle* codes_handle_new_from_message(codes_context* c, const void* data,
 /**
 *  Create a handle from a user message in memory. The message will not be freed at the end.
 *  The message will be copied as soon as a modification is needed.
-*  This function works also with multi field messages.
+*  This function works also with multi-field messages.
 *
 * @param c           : the context from which the handle will be created (NULL for default context)
 * @param data        : the actual message
@@ -462,7 +461,7 @@ codes_handle* codes_handle_new_from_message_copy(codes_context* c, const void* d
  *  The message is copied at the creation of the handle
  *
  * @param c           : the context from which the handle will be created (NULL for default context)
- * @param sample_name : the name of the sample file (without the .tmpl extension)
+ * @param sample_name : the name of the GRIB sample file
  * @return            the new handle, NULL if the resource is invalid or a problem is encountered
  */
 codes_handle* codes_grib_handle_new_from_samples(codes_context* c, const char* sample_name);
@@ -472,11 +471,22 @@ codes_handle* codes_grib_handle_new_from_samples(codes_context* c, const char* s
  *  The message is copied at the creation of the handle
  *
  * @param c           : the context from which the handle will be created (NULL for default context)
- * @param sample_name : the name of the sample file (without the .tmpl extension)
+ * @param sample_name : the name of the BUFR sample file
  * @return            the new handle, NULL if the resource is invalid or a problem is encountered
  */
 codes_handle* codes_bufr_handle_new_from_samples(codes_context* c, const char* sample_name);
 
+/**
+ *  Create a handle from a file contained in a samples directory.
+ *  The samples file can be GRIB, BUFR etc. Its type will be determined at runtime.
+ *  The message is copied at the creation of the handle
+ *
+ * @param c           : the context from which the handle will be created (NULL for default context)
+ * @param sample_name : the name of the sample file
+ * @return            the new handle, NULL if the resource is invalid or a problem is encountered
+ */
+codes_handle* codes_handle_new_from_samples(codes_context* c, const char* sample_name);
+
 
 /**
 *  Clone an existing handle using the context of the original handle,
@@ -685,7 +695,7 @@ int codes_grib_nearest_delete(codes_nearest* nearest);
 * Find the nearest point of a set of points whose latitudes and longitudes
 * are given in the inlats, inlons arrays respectively.
 * If the flag is_lsm is 1 the nearest land point is returned and the
-* grib passed as handle (h) is considered a land sea mask.
+* GRIB passed as handle (h) is considered a land sea mask.
 * The land nearest point is the nearest point with land sea mask value>=0.5.
 * If no nearest land points are found the nearest value is returned.
 * If the flag is_lsm is 0 the nearest point is returned.
@@ -779,16 +789,16 @@ int codes_get_double(const codes_handle* h, const char* key, double* value);
 int codes_get_double_element(const codes_handle* h, const char* key, int i, double* value);
 
 /**
-*  Get as double array the elements of the "key" array whose indexes are listed in the input array i
+*  Get as double array the elements of the "key" array whose indexes are listed in the input array "index_array"
 *
 * @param h           : the handle to get the data from
 * @param key         : the key to be searched
-* @param i           : zero-based array of indexes
-* @param size        : size of the i and value arrays
+* @param index_array : zero-based array of indexes
+* @param size        : size of the index_array and value arrays
 * @param value       : the double array for the data values
 * @return            0 if OK, integer value on error
 */
-int codes_get_double_elements(const codes_handle* h, const char* key, int* i, long size, double* value);
+int codes_get_double_elements(const codes_handle* h, const char* key, const int* index_array, long size, double* value);
 
 /**
 *  Get a string value from a key, if several keys of the same name are present, the last one is returned
@@ -1067,14 +1077,14 @@ void codes_context_set_definitions_path(codes_context* c, const char* path);
 void codes_context_set_samples_path(codes_context* c, const char* path);
 
 /**
-*  Turn on support for multiple fields in single GRIB messages
+*  Turn on support for multi-fields in single GRIB messages
 *
 * @param c            : the context to be modified
 */
 void codes_grib_multi_support_on(codes_context* c);
 
 /**
-*  Turn off support for multiple fields in single GRIB messages
+*  Turn off support for multi-fields in single GRIB messages
 *
 * @param c            : the context to be modified
 */
@@ -1106,6 +1116,8 @@ long codes_get_api_version(void);
 */
 const char* codes_get_git_sha1(void);
 
+const char* codes_get_build_date(void);
+
 /**
 *  Get the package name
 *
@@ -1229,9 +1241,6 @@ int codes_get_product_kind(const codes_handle* h, ProductKind* product_kind);
 int codes_check_message_header(const void* bytes, size_t length, ProductKind product);
 int codes_check_message_footer(const void* bytes, size_t length, ProductKind product);
 
-codes_box* codes_box_new(codes_handle* h, int* error);
-codes_points* codes_box_get_points(codes_box* box, double north, double west, double south, double east, int* err);
-int codes_points_get_values(codes_handle* h, codes_points* points, double* val);
 
 /* --------------------------------------- */
 
