@@ -64,9 +64,9 @@ typedef struct grib_accessor_bits
     grib_accessor att;
     /* Members defined in gen */
     /* Members defined in bits */
-    const char* argument;
-    long start;
-    long len;
+    const char*    argument;
+    long    start;
+    long    len;
     double referenceValue;
     double referenceValuePresent;
     double scale;
@@ -75,46 +75,47 @@ typedef struct grib_accessor_bits
 extern grib_accessor_class* grib_accessor_class_gen;
 
 static grib_accessor_class _grib_accessor_class_bits = {
-    &grib_accessor_class_gen,   /* super                     */
-    "bits",                     /* name                      */
-    sizeof(grib_accessor_bits), /* size                      */
-    0,                          /* inited */
-    &init_class,                /* init_class */
-    &init,                      /* init                      */
-    0,                          /* post_init                      */
-    0,                          /* free mem                       */
-    0,                          /* describes himself         */
-    0,                          /* get length of section     */
-    0,                          /* get length of string      */
-    0,                          /* get number of values      */
-    &byte_count,                /* get number of bytes      */
-    0,                          /* get offset to bytes           */
-    &get_native_type,           /* get native type               */
-    0,                          /* get sub_section                */
-    0,                          /* grib_pack procedures long      */
-    0,                          /* grib_pack procedures long      */
-    &pack_long,                 /* grib_pack procedures long      */
-    &unpack_long,               /* grib_unpack procedures long    */
-    &pack_double,               /* grib_pack procedures double    */
-    &unpack_double,             /* grib_unpack procedures double  */
-    0,                          /* grib_pack procedures string    */
-    &unpack_string,             /* grib_unpack procedures string  */
-    0,                          /* grib_pack array procedures string    */
-    0,                          /* grib_unpack array procedures string  */
-    0,                          /* grib_pack procedures bytes     */
-    &unpack_bytes,              /* grib_unpack procedures bytes   */
-    0,                          /* pack_expression */
-    0,                          /* notify_change   */
-    0,                          /* update_size   */
-    0,                          /* preferred_size   */
-    0,                          /* resize   */
-    0,                          /* nearest_smaller_value */
-    0,                          /* next accessor    */
-    0,                          /* compare vs. another accessor   */
-    0,                          /* unpack only ith value          */
-    0,                          /* unpack a subarray         */
-    0,                          /* clear          */
-    0,                          /* clone accessor          */
+    &grib_accessor_class_gen,                      /* super */
+    "bits",                      /* name */
+    sizeof(grib_accessor_bits),  /* size */
+    0,                           /* inited */
+    &init_class,                 /* init_class */
+    &init,                       /* init */
+    0,                  /* post_init */
+    0,                    /* free mem */
+    0,                       /* describes himself */
+    0,                /* get length of section */
+    0,              /* get length of string */
+    0,                /* get number of values */
+    &byte_count,                 /* get number of bytes */
+    0,                /* get offset to bytes */
+    &get_native_type,            /* get native type */
+    0,                /* get sub_section */
+    0,               /* grib_pack procedures long */
+    0,                 /* grib_pack procedures long */
+    &pack_long,                  /* grib_pack procedures long */
+    &unpack_long,                /* grib_unpack procedures long */
+    &pack_double,                /* grib_pack procedures double */
+    &unpack_double,              /* grib_unpack procedures double */
+    0,                /* grib_pack procedures string */
+    &unpack_string,              /* grib_unpack procedures string */
+    0,          /* grib_pack array procedures string */
+    0,        /* grib_unpack array procedures string */
+    0,                 /* grib_pack procedures bytes */
+    &unpack_bytes,               /* grib_unpack procedures bytes */
+    0,            /* pack_expression */
+    0,              /* notify_change */
+    0,                /* update_size */
+    0,             /* preferred_size */
+    0,                     /* resize */
+    0,      /* nearest_smaller_value */
+    0,                       /* next accessor */
+    0,                    /* compare vs. another accessor */
+    0,      /* unpack only ith value */
+    0,  /* unpack a given set of elements */
+    0,     /* unpack a subarray */
+    0,                      /* clear */
+    0,                 /* clone accessor */
 };
 
 
@@ -123,30 +124,31 @@ grib_accessor_class* grib_accessor_class_bits = &_grib_accessor_class_bits;
 
 static void init_class(grib_accessor_class* c)
 {
-    c->dump                   = (*(c->super))->dump;
-    c->next_offset            = (*(c->super))->next_offset;
-    c->string_length          = (*(c->super))->string_length;
-    c->value_count            = (*(c->super))->value_count;
-    c->byte_offset            = (*(c->super))->byte_offset;
-    c->sub_section            = (*(c->super))->sub_section;
-    c->pack_missing           = (*(c->super))->pack_missing;
-    c->is_missing             = (*(c->super))->is_missing;
-    c->pack_string            = (*(c->super))->pack_string;
-    c->pack_string_array      = (*(c->super))->pack_string_array;
-    c->unpack_string_array    = (*(c->super))->unpack_string_array;
-    c->pack_bytes             = (*(c->super))->pack_bytes;
-    c->pack_expression        = (*(c->super))->pack_expression;
-    c->notify_change          = (*(c->super))->notify_change;
-    c->update_size            = (*(c->super))->update_size;
-    c->preferred_size         = (*(c->super))->preferred_size;
-    c->resize                 = (*(c->super))->resize;
-    c->nearest_smaller_value  = (*(c->super))->nearest_smaller_value;
-    c->next                   = (*(c->super))->next;
-    c->compare                = (*(c->super))->compare;
-    c->unpack_double_element  = (*(c->super))->unpack_double_element;
-    c->unpack_double_subarray = (*(c->super))->unpack_double_subarray;
-    c->clear                  = (*(c->super))->clear;
-    c->make_clone             = (*(c->super))->make_clone;
+    c->dump    =    (*(c->super))->dump;
+    c->next_offset    =    (*(c->super))->next_offset;
+    c->string_length    =    (*(c->super))->string_length;
+    c->value_count    =    (*(c->super))->value_count;
+    c->byte_offset    =    (*(c->super))->byte_offset;
+    c->sub_section    =    (*(c->super))->sub_section;
+    c->pack_missing    =    (*(c->super))->pack_missing;
+    c->is_missing    =    (*(c->super))->is_missing;
+    c->pack_string    =    (*(c->super))->pack_string;
+    c->pack_string_array    =    (*(c->super))->pack_string_array;
+    c->unpack_string_array    =    (*(c->super))->unpack_string_array;
+    c->pack_bytes    =    (*(c->super))->pack_bytes;
+    c->pack_expression    =    (*(c->super))->pack_expression;
+    c->notify_change    =    (*(c->super))->notify_change;
+    c->update_size    =    (*(c->super))->update_size;
+    c->preferred_size    =    (*(c->super))->preferred_size;
+    c->resize    =    (*(c->super))->resize;
+    c->nearest_smaller_value    =    (*(c->super))->nearest_smaller_value;
+    c->next    =    (*(c->super))->next;
+    c->compare    =    (*(c->super))->compare;
+    c->unpack_double_element    =    (*(c->super))->unpack_double_element;
+    c->unpack_double_element_set    =    (*(c->super))->unpack_double_element_set;
+    c->unpack_double_subarray    =    (*(c->super))->unpack_double_subarray;
+    c->clear    =    (*(c->super))->clear;
+    c->make_clone    =    (*(c->super))->make_clone;
 }
 
 /* END_CLASS_IMP */
