@@ -66,46 +66,47 @@ typedef struct grib_accessor_bufr_extract_area_subsets
 extern grib_accessor_class* grib_accessor_class_gen;
 
 static grib_accessor_class _grib_accessor_class_bufr_extract_area_subsets = {
-    &grib_accessor_class_gen,                        /* super                     */
-    "bufr_extract_area_subsets",                     /* name                      */
-    sizeof(grib_accessor_bufr_extract_area_subsets), /* size                      */
-    0,                                               /* inited */
-    &init_class,                                     /* init_class */
-    &init,                                           /* init                      */
-    0,                                               /* post_init                      */
-    0,                                               /* free mem                       */
-    0,                                               /* describes himself         */
-    0,                                               /* get length of section     */
-    0,                                               /* get length of string      */
-    0,                                               /* get number of values      */
-    0,                                               /* get number of bytes      */
-    0,                                               /* get offset to bytes           */
-    &get_native_type,                                /* get native type               */
-    0,                                               /* get sub_section                */
-    0,                                               /* grib_pack procedures long      */
-    0,                                               /* grib_pack procedures long      */
-    &pack_long,                                      /* grib_pack procedures long      */
-    0,                                               /* grib_unpack procedures long    */
-    0,                                               /* grib_pack procedures double    */
-    0,                                               /* grib_unpack procedures double  */
-    0,                                               /* grib_pack procedures string    */
-    0,                                               /* grib_unpack procedures string  */
-    0,                                               /* grib_pack array procedures string    */
-    0,                                               /* grib_unpack array procedures string  */
-    0,                                               /* grib_pack procedures bytes     */
-    0,                                               /* grib_unpack procedures bytes   */
-    0,                                               /* pack_expression */
-    0,                                               /* notify_change   */
-    0,                                               /* update_size   */
-    0,                                               /* preferred_size   */
-    0,                                               /* resize   */
-    0,                                               /* nearest_smaller_value */
-    0,                                               /* next accessor    */
-    0,                                               /* compare vs. another accessor   */
-    0,                                               /* unpack only ith value          */
-    0,                                               /* unpack a subarray         */
-    0,                                               /* clear          */
-    0,                                               /* clone accessor          */
+    &grib_accessor_class_gen,                      /* super */
+    "bufr_extract_area_subsets",                      /* name */
+    sizeof(grib_accessor_bufr_extract_area_subsets),  /* size */
+    0,                           /* inited */
+    &init_class,                 /* init_class */
+    &init,                       /* init */
+    0,                  /* post_init */
+    0,                    /* free mem */
+    0,                       /* describes himself */
+    0,                /* get length of section */
+    0,              /* get length of string */
+    0,                /* get number of values */
+    0,                 /* get number of bytes */
+    0,                /* get offset to bytes */
+    &get_native_type,            /* get native type */
+    0,                /* get sub_section */
+    0,               /* grib_pack procedures long */
+    0,                 /* grib_pack procedures long */
+    &pack_long,                  /* grib_pack procedures long */
+    0,                /* grib_unpack procedures long */
+    0,                /* grib_pack procedures double */
+    0,              /* grib_unpack procedures double */
+    0,                /* grib_pack procedures string */
+    0,              /* grib_unpack procedures string */
+    0,          /* grib_pack array procedures string */
+    0,        /* grib_unpack array procedures string */
+    0,                 /* grib_pack procedures bytes */
+    0,               /* grib_unpack procedures bytes */
+    0,            /* pack_expression */
+    0,              /* notify_change */
+    0,                /* update_size */
+    0,             /* preferred_size */
+    0,                     /* resize */
+    0,      /* nearest_smaller_value */
+    0,                       /* next accessor */
+    0,                    /* compare vs. another accessor */
+    0,      /* unpack only ith value */
+    0,  /* unpack a given set of elements */
+    0,     /* unpack a subarray */
+    0,                      /* clear */
+    0,                 /* clone accessor */
 };
 
 
@@ -114,36 +115,37 @@ grib_accessor_class* grib_accessor_class_bufr_extract_area_subsets = &_grib_acce
 
 static void init_class(grib_accessor_class* c)
 {
-    c->dump                   = (*(c->super))->dump;
-    c->next_offset            = (*(c->super))->next_offset;
-    c->string_length          = (*(c->super))->string_length;
-    c->value_count            = (*(c->super))->value_count;
-    c->byte_count             = (*(c->super))->byte_count;
-    c->byte_offset            = (*(c->super))->byte_offset;
-    c->sub_section            = (*(c->super))->sub_section;
-    c->pack_missing           = (*(c->super))->pack_missing;
-    c->is_missing             = (*(c->super))->is_missing;
-    c->unpack_long            = (*(c->super))->unpack_long;
-    c->pack_double            = (*(c->super))->pack_double;
-    c->unpack_double          = (*(c->super))->unpack_double;
-    c->pack_string            = (*(c->super))->pack_string;
-    c->unpack_string          = (*(c->super))->unpack_string;
-    c->pack_string_array      = (*(c->super))->pack_string_array;
-    c->unpack_string_array    = (*(c->super))->unpack_string_array;
-    c->pack_bytes             = (*(c->super))->pack_bytes;
-    c->unpack_bytes           = (*(c->super))->unpack_bytes;
-    c->pack_expression        = (*(c->super))->pack_expression;
-    c->notify_change          = (*(c->super))->notify_change;
-    c->update_size            = (*(c->super))->update_size;
-    c->preferred_size         = (*(c->super))->preferred_size;
-    c->resize                 = (*(c->super))->resize;
-    c->nearest_smaller_value  = (*(c->super))->nearest_smaller_value;
-    c->next                   = (*(c->super))->next;
-    c->compare                = (*(c->super))->compare;
-    c->unpack_double_element  = (*(c->super))->unpack_double_element;
-    c->unpack_double_subarray = (*(c->super))->unpack_double_subarray;
-    c->clear                  = (*(c->super))->clear;
-    c->make_clone             = (*(c->super))->make_clone;
+    c->dump    =    (*(c->super))->dump;
+    c->next_offset    =    (*(c->super))->next_offset;
+    c->string_length    =    (*(c->super))->string_length;
+    c->value_count    =    (*(c->super))->value_count;
+    c->byte_count    =    (*(c->super))->byte_count;
+    c->byte_offset    =    (*(c->super))->byte_offset;
+    c->sub_section    =    (*(c->super))->sub_section;
+    c->pack_missing    =    (*(c->super))->pack_missing;
+    c->is_missing    =    (*(c->super))->is_missing;
+    c->unpack_long    =    (*(c->super))->unpack_long;
+    c->pack_double    =    (*(c->super))->pack_double;
+    c->unpack_double    =    (*(c->super))->unpack_double;
+    c->pack_string    =    (*(c->super))->pack_string;
+    c->unpack_string    =    (*(c->super))->unpack_string;
+    c->pack_string_array    =    (*(c->super))->pack_string_array;
+    c->unpack_string_array    =    (*(c->super))->unpack_string_array;
+    c->pack_bytes    =    (*(c->super))->pack_bytes;
+    c->unpack_bytes    =    (*(c->super))->unpack_bytes;
+    c->pack_expression    =    (*(c->super))->pack_expression;
+    c->notify_change    =    (*(c->super))->notify_change;
+    c->update_size    =    (*(c->super))->update_size;
+    c->preferred_size    =    (*(c->super))->preferred_size;
+    c->resize    =    (*(c->super))->resize;
+    c->nearest_smaller_value    =    (*(c->super))->nearest_smaller_value;
+    c->next    =    (*(c->super))->next;
+    c->compare    =    (*(c->super))->compare;
+    c->unpack_double_element    =    (*(c->super))->unpack_double_element;
+    c->unpack_double_element_set    =    (*(c->super))->unpack_double_element_set;
+    c->unpack_double_subarray    =    (*(c->super))->unpack_double_subarray;
+    c->clear    =    (*(c->super))->clear;
+    c->make_clone    =    (*(c->super))->make_clone;
 }
 
 /* END_CLASS_IMP */
@@ -196,8 +198,8 @@ static int select_area(grib_accessor* a)
     grib_iarray* subsets;
     long* subsets_ar = 0;
     size_t nsubsets  = 0;
-    char latstr[20]  = {0,};
-    char lonstr[20] = {0,};
+    char latstr[32]  = {0,};
+    char lonstr[32] = {0,};
 
     ret = grib_get_long(h, "compressedData", &compressed);
     if (ret)
@@ -332,14 +334,9 @@ static int select_area(grib_accessor* a)
 
 static int pack_long(grib_accessor* a, const long* val, size_t* len)
 {
-    int err = 0;
     /*grib_accessor_bufr_extract_area_subsets *self =(grib_accessor_bufr_extract_area_subsets*)a;*/
 
     if (*len == 0)
         return GRIB_SUCCESS;
-    err = select_area(a);
-    if (err)
-        return err;
-
-    return err;
+    return select_area(a);
 }
