@@ -68,46 +68,47 @@ typedef struct grib_accessor_group
 extern grib_accessor_class* grib_accessor_class_gen;
 
 static grib_accessor_class _grib_accessor_class_group = {
-    &grib_accessor_class_gen,    /* super                     */
-    "group",                     /* name                      */
-    sizeof(grib_accessor_group), /* size                      */
+    &grib_accessor_class_gen,                      /* super */
+    "group",                      /* name */
+    sizeof(grib_accessor_group),  /* size */
     0,                           /* inited */
     &init_class,                 /* init_class */
-    &init,                       /* init                      */
-    &post_init,                  /* post_init                      */
-    0,                           /* free mem                       */
-    &dump,                       /* describes himself         */
-    &next_offset,                /* get length of section     */
-    &string_length,              /* get length of string      */
-    &value_count,                /* get number of values      */
-    0,                           /* get number of bytes      */
-    0,                           /* get offset to bytes           */
-    &get_native_type,            /* get native type               */
-    0,                           /* get sub_section                */
-    0,                           /* grib_pack procedures long      */
-    0,                           /* grib_pack procedures long      */
-    &pack_long,                  /* grib_pack procedures long      */
-    &unpack_long,                /* grib_unpack procedures long    */
-    &pack_double,                /* grib_pack procedures double    */
-    &unpack_double,              /* grib_unpack procedures double  */
-    &pack_string,                /* grib_pack procedures string    */
-    &unpack_string,              /* grib_unpack procedures string  */
-    0,                           /* grib_pack array procedures string    */
-    0,                           /* grib_unpack array procedures string  */
-    0,                           /* grib_pack procedures bytes     */
-    0,                           /* grib_unpack procedures bytes   */
-    0,                           /* pack_expression */
-    0,                           /* notify_change   */
-    0,                           /* update_size   */
-    0,                           /* preferred_size   */
-    0,                           /* resize   */
-    0,                           /* nearest_smaller_value */
-    0,                           /* next accessor    */
-    &compare,                    /* compare vs. another accessor   */
-    0,                           /* unpack only ith value          */
-    0,                           /* unpack a subarray         */
-    0,                           /* clear          */
-    0,                           /* clone accessor          */
+    &init,                       /* init */
+    &post_init,                  /* post_init */
+    0,                    /* free mem */
+    &dump,                       /* describes himself */
+    &next_offset,                /* get length of section */
+    &string_length,              /* get length of string */
+    &value_count,                /* get number of values */
+    0,                 /* get number of bytes */
+    0,                /* get offset to bytes */
+    &get_native_type,            /* get native type */
+    0,                /* get sub_section */
+    0,               /* grib_pack procedures long */
+    0,                 /* grib_pack procedures long */
+    &pack_long,                  /* grib_pack procedures long */
+    &unpack_long,                /* grib_unpack procedures long */
+    &pack_double,                /* grib_pack procedures double */
+    &unpack_double,              /* grib_unpack procedures double */
+    &pack_string,                /* grib_pack procedures string */
+    &unpack_string,              /* grib_unpack procedures string */
+    0,          /* grib_pack array procedures string */
+    0,        /* grib_unpack array procedures string */
+    0,                 /* grib_pack procedures bytes */
+    0,               /* grib_unpack procedures bytes */
+    0,            /* pack_expression */
+    0,              /* notify_change */
+    0,                /* update_size */
+    0,             /* preferred_size */
+    0,                     /* resize */
+    0,      /* nearest_smaller_value */
+    0,                       /* next accessor */
+    &compare,                    /* compare vs. another accessor */
+    0,      /* unpack only ith value */
+    0,  /* unpack a given set of elements */
+    0,     /* unpack a subarray */
+    0,                      /* clear */
+    0,                 /* clone accessor */
 };
 
 
@@ -116,26 +117,27 @@ grib_accessor_class* grib_accessor_class_group = &_grib_accessor_class_group;
 
 static void init_class(grib_accessor_class* c)
 {
-    c->byte_count             = (*(c->super))->byte_count;
-    c->byte_offset            = (*(c->super))->byte_offset;
-    c->sub_section            = (*(c->super))->sub_section;
-    c->pack_missing           = (*(c->super))->pack_missing;
-    c->is_missing             = (*(c->super))->is_missing;
-    c->pack_string_array      = (*(c->super))->pack_string_array;
-    c->unpack_string_array    = (*(c->super))->unpack_string_array;
-    c->pack_bytes             = (*(c->super))->pack_bytes;
-    c->unpack_bytes           = (*(c->super))->unpack_bytes;
-    c->pack_expression        = (*(c->super))->pack_expression;
-    c->notify_change          = (*(c->super))->notify_change;
-    c->update_size            = (*(c->super))->update_size;
-    c->preferred_size         = (*(c->super))->preferred_size;
-    c->resize                 = (*(c->super))->resize;
-    c->nearest_smaller_value  = (*(c->super))->nearest_smaller_value;
-    c->next                   = (*(c->super))->next;
-    c->unpack_double_element  = (*(c->super))->unpack_double_element;
-    c->unpack_double_subarray = (*(c->super))->unpack_double_subarray;
-    c->clear                  = (*(c->super))->clear;
-    c->make_clone             = (*(c->super))->make_clone;
+    c->byte_count    =    (*(c->super))->byte_count;
+    c->byte_offset    =    (*(c->super))->byte_offset;
+    c->sub_section    =    (*(c->super))->sub_section;
+    c->pack_missing    =    (*(c->super))->pack_missing;
+    c->is_missing    =    (*(c->super))->is_missing;
+    c->pack_string_array    =    (*(c->super))->pack_string_array;
+    c->unpack_string_array    =    (*(c->super))->unpack_string_array;
+    c->pack_bytes    =    (*(c->super))->pack_bytes;
+    c->unpack_bytes    =    (*(c->super))->unpack_bytes;
+    c->pack_expression    =    (*(c->super))->pack_expression;
+    c->notify_change    =    (*(c->super))->notify_change;
+    c->update_size    =    (*(c->super))->update_size;
+    c->preferred_size    =    (*(c->super))->preferred_size;
+    c->resize    =    (*(c->super))->resize;
+    c->nearest_smaller_value    =    (*(c->super))->nearest_smaller_value;
+    c->next    =    (*(c->super))->next;
+    c->unpack_double_element    =    (*(c->super))->unpack_double_element;
+    c->unpack_double_element_set    =    (*(c->super))->unpack_double_element_set;
+    c->unpack_double_subarray    =    (*(c->super))->unpack_double_subarray;
+    c->clear    =    (*(c->super))->clear;
+    c->make_clone    =    (*(c->super))->make_clone;
 }
 
 /* END_CLASS_IMP */
@@ -207,7 +209,8 @@ static int unpack_string(grib_accessor* a, char* val, size_t* len)
     int i = 0;
 
     if (len[0] < (a->length + 1)) {
-        grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name, a->length + 1);
+        grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%lu) for %s it contains %ld values",
+                len[0], a->name, a->length + 1);
         len[0] = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
@@ -248,7 +251,7 @@ static int unpack_long(grib_accessor* a, long* v, size_t* len)
         return err;
 
     i = 0;
-    while (val[i] == ' ' && val[i] != 0 && i < l - 1)
+    while (i < l - 1 && val[i] == ' ')
         i++;
 
     if (val[i] == 0) {
