@@ -82,46 +82,47 @@ typedef struct grib_accessor_smart_table
 extern grib_accessor_class* grib_accessor_class_unsigned;
 
 static grib_accessor_class _grib_accessor_class_smart_table = {
-    &grib_accessor_class_unsigned,     /* super                     */
-    "smart_table",                     /* name                      */
-    sizeof(grib_accessor_smart_table), /* size                      */
-    0,                                 /* inited */
-    &init_class,                       /* init_class */
-    &init,                             /* init                      */
-    0,                                 /* post_init                      */
-    &destroy,                          /* free mem                       */
-    &dump,                             /* describes himself         */
-    0,                                 /* get length of section     */
-    0,                                 /* get length of string      */
-    &value_count,                      /* get number of values      */
-    0,                                 /* get number of bytes      */
-    0,                                 /* get offset to bytes           */
-    &get_native_type,                  /* get native type               */
-    0,                                 /* get sub_section                */
-    0,                                 /* grib_pack procedures long      */
-    0,                                 /* grib_pack procedures long      */
-    0,                                 /* grib_pack procedures long      */
-    &unpack_long,                      /* grib_unpack procedures long    */
-    0,                                 /* grib_pack procedures double    */
-    0,                                 /* grib_unpack procedures double  */
-    0,                                 /* grib_pack procedures string    */
-    &unpack_string,                    /* grib_unpack procedures string  */
-    0,                                 /* grib_pack array procedures string    */
-    0,                                 /* grib_unpack array procedures string  */
-    0,                                 /* grib_pack procedures bytes     */
-    0,                                 /* grib_unpack procedures bytes   */
-    0,                                 /* pack_expression */
-    0,                                 /* notify_change   */
-    0,                                 /* update_size   */
-    0,                                 /* preferred_size   */
-    0,                                 /* resize   */
-    0,                                 /* nearest_smaller_value */
-    0,                                 /* next accessor    */
-    0,                                 /* compare vs. another accessor   */
-    0,                                 /* unpack only ith value          */
-    0,                                 /* unpack a subarray         */
-    0,                                 /* clear          */
-    0,                                 /* clone accessor          */
+    &grib_accessor_class_unsigned,                      /* super */
+    "smart_table",                      /* name */
+    sizeof(grib_accessor_smart_table),  /* size */
+    0,                           /* inited */
+    &init_class,                 /* init_class */
+    &init,                       /* init */
+    0,                  /* post_init */
+    &destroy,                    /* free mem */
+    &dump,                       /* describes himself */
+    0,                /* get length of section */
+    0,              /* get length of string */
+    &value_count,                /* get number of values */
+    0,                 /* get number of bytes */
+    0,                /* get offset to bytes */
+    &get_native_type,            /* get native type */
+    0,                /* get sub_section */
+    0,               /* grib_pack procedures long */
+    0,                 /* grib_pack procedures long */
+    0,                  /* grib_pack procedures long */
+    &unpack_long,                /* grib_unpack procedures long */
+    0,                /* grib_pack procedures double */
+    0,              /* grib_unpack procedures double */
+    0,                /* grib_pack procedures string */
+    &unpack_string,              /* grib_unpack procedures string */
+    0,          /* grib_pack array procedures string */
+    0,        /* grib_unpack array procedures string */
+    0,                 /* grib_pack procedures bytes */
+    0,               /* grib_unpack procedures bytes */
+    0,            /* pack_expression */
+    0,              /* notify_change */
+    0,                /* update_size */
+    0,             /* preferred_size */
+    0,                     /* resize */
+    0,      /* nearest_smaller_value */
+    0,                       /* next accessor */
+    0,                    /* compare vs. another accessor */
+    0,      /* unpack only ith value */
+    0,  /* unpack a given set of elements */
+    0,     /* unpack a subarray */
+    0,                      /* clear */
+    0,                 /* clone accessor */
 };
 
 
@@ -130,33 +131,34 @@ grib_accessor_class* grib_accessor_class_smart_table = &_grib_accessor_class_sma
 
 static void init_class(grib_accessor_class* c)
 {
-    c->next_offset            = (*(c->super))->next_offset;
-    c->string_length          = (*(c->super))->string_length;
-    c->byte_count             = (*(c->super))->byte_count;
-    c->byte_offset            = (*(c->super))->byte_offset;
-    c->sub_section            = (*(c->super))->sub_section;
-    c->pack_missing           = (*(c->super))->pack_missing;
-    c->is_missing             = (*(c->super))->is_missing;
-    c->pack_long              = (*(c->super))->pack_long;
-    c->pack_double            = (*(c->super))->pack_double;
-    c->unpack_double          = (*(c->super))->unpack_double;
-    c->pack_string            = (*(c->super))->pack_string;
-    c->pack_string_array      = (*(c->super))->pack_string_array;
-    c->unpack_string_array    = (*(c->super))->unpack_string_array;
-    c->pack_bytes             = (*(c->super))->pack_bytes;
-    c->unpack_bytes           = (*(c->super))->unpack_bytes;
-    c->pack_expression        = (*(c->super))->pack_expression;
-    c->notify_change          = (*(c->super))->notify_change;
-    c->update_size            = (*(c->super))->update_size;
-    c->preferred_size         = (*(c->super))->preferred_size;
-    c->resize                 = (*(c->super))->resize;
-    c->nearest_smaller_value  = (*(c->super))->nearest_smaller_value;
-    c->next                   = (*(c->super))->next;
-    c->compare                = (*(c->super))->compare;
-    c->unpack_double_element  = (*(c->super))->unpack_double_element;
-    c->unpack_double_subarray = (*(c->super))->unpack_double_subarray;
-    c->clear                  = (*(c->super))->clear;
-    c->make_clone             = (*(c->super))->make_clone;
+    c->next_offset    =    (*(c->super))->next_offset;
+    c->string_length    =    (*(c->super))->string_length;
+    c->byte_count    =    (*(c->super))->byte_count;
+    c->byte_offset    =    (*(c->super))->byte_offset;
+    c->sub_section    =    (*(c->super))->sub_section;
+    c->pack_missing    =    (*(c->super))->pack_missing;
+    c->is_missing    =    (*(c->super))->is_missing;
+    c->pack_long    =    (*(c->super))->pack_long;
+    c->pack_double    =    (*(c->super))->pack_double;
+    c->unpack_double    =    (*(c->super))->unpack_double;
+    c->pack_string    =    (*(c->super))->pack_string;
+    c->pack_string_array    =    (*(c->super))->pack_string_array;
+    c->unpack_string_array    =    (*(c->super))->unpack_string_array;
+    c->pack_bytes    =    (*(c->super))->pack_bytes;
+    c->unpack_bytes    =    (*(c->super))->unpack_bytes;
+    c->pack_expression    =    (*(c->super))->pack_expression;
+    c->notify_change    =    (*(c->super))->notify_change;
+    c->update_size    =    (*(c->super))->update_size;
+    c->preferred_size    =    (*(c->super))->preferred_size;
+    c->resize    =    (*(c->super))->resize;
+    c->nearest_smaller_value    =    (*(c->super))->nearest_smaller_value;
+    c->next    =    (*(c->super))->next;
+    c->compare    =    (*(c->super))->compare;
+    c->unpack_double_element    =    (*(c->super))->unpack_double_element;
+    c->unpack_double_element_set    =    (*(c->super))->unpack_double_element_set;
+    c->unpack_double_subarray    =    (*(c->super))->unpack_double_subarray;
+    c->clear    =    (*(c->super))->clear;
+    c->make_clone    =    (*(c->super))->make_clone;
 }
 
 /* END_CLASS_IMP */
@@ -281,7 +283,10 @@ static grib_smart_table* load_table(grib_accessor_smart_table* self)
         next = next->next;
     }
 
-    size = (1UL << self->widthOfCode); /* 2 ^ self->widthOfCode */
+    /* Note: self->widthOfCode is chosen so that 2^width is bigger than the maximum descriptor code,
+     * which for BUFR4 is the Table C operator 243255
+     */
+    size = (1ULL << self->widthOfCode); /* = 2^self->widthOfCode (as a 64 bit number) */
 
     t                  = (grib_smart_table*)grib_context_malloc_clear_persistent(c, sizeof(grib_smart_table));
     t->entries         = (grib_smart_table_entry*)grib_context_malloc_clear_persistent(c, size * sizeof(grib_smart_table_entry));
@@ -309,9 +314,7 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
 {
     char line[1024] = {0,};
     FILE* f = NULL;
-    int lineNumber;
-    int numberOfColumns;
-    int code;
+    int lineNumber, numberOfColumns, code;
 
     grib_context_log(c, GRIB_LOG_DEBUG, "Loading code table from %s", filename);
 
@@ -360,7 +363,7 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
 
         *p = 0;
 
-        code = atol(s);
+        code = atoi(s);
 
         p++;
         s = p;
@@ -370,12 +373,14 @@ static int grib_load_smart_table(grib_context* c, const char* filename,
         *p = 0;
 
         numberOfColumns = 0;
+        /* The highest possible descriptor code must fit into t->numberOfEntries */
+        DebugAssert(code < t->numberOfEntries);
         while (*s) {
             char* tcol = t->entries[code].column[numberOfColumns];
             if ( tcol ) grib_context_free_persistent(c, tcol);
             t->entries[code].column[numberOfColumns] = grib_context_strdup_persistent(c, s);
             numberOfColumns++;
-            Assert(numberOfColumns < MAX_SMART_TABLE_COLUMNS);
+            DebugAssert(numberOfColumns < MAX_SMART_TABLE_COLUMNS);
 
             p++;
             s = p;
@@ -569,7 +574,7 @@ static int unpack_long(grib_accessor* a, long* val, size_t* len)
 
     if (*len < self->tableCodesSize) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, self->tableCodesSize);
+                         "Wrong size (%lu) for %s it contains %lu values", *len, a->name, self->tableCodesSize);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
