@@ -22,7 +22,8 @@ void grib_darray_print(const char* title, const grib_darray* darray)
     printf("\n");
 }
 
-grib_darray* grib_darray_new_from_array(grib_context* c, double* a, size_t size)
+#if 0
+grib_darray* grib_darray_new_from_array(grib_context* c, double* src_array, size_t size)
 {
     size_t i;
     grib_darray* v;
@@ -32,11 +33,12 @@ grib_darray* grib_darray_new_from_array(grib_context* c, double* a, size_t size)
 
     v = grib_darray_new(c, size, 100);
     for (i = 0; i < size; i++)
-        v->v[i] = a[i];
+        v->v[i] = src_array[i];
     v->n       = size;
     v->context = c;
     return v;
 }
+#endif
 
 grib_darray* grib_darray_new(grib_context* c, size_t size, size_t incsize)
 {
