@@ -42,47 +42,46 @@ or edit "expression.class" and rerun ./make_class.pl
 typedef const char* string; /* to keep make_class.pl happy */
 
 
-static void init_class(grib_expression_class*);
+static void init_class              (grib_expression_class*);
 
-static void destroy(grib_context*, grib_expression* e);
+static void        destroy(grib_context*,grib_expression* e);
 
-static void print(grib_context*, grib_expression*, grib_handle*);
-static void add_dependency(grib_expression* e, grib_accessor* observer);
+static void        print(grib_context*,grib_expression*,grib_handle*);
+static void        add_dependency(grib_expression* e, grib_accessor* observer);
 static string get_name(grib_expression* e);
 
-static int native_type(grib_expression*, grib_handle*);
+static int        native_type(grib_expression*,grib_handle*);
 
-static int evaluate_long(grib_expression*, grib_handle*, long*);
-static int evaluate_double(grib_expression*, grib_handle*, double*);
-static string evaluate_string(grib_expression*, grib_handle*, char*, size_t*, int*);
+static int        evaluate_long(grib_expression*,grib_handle*,long*);
+static int      evaluate_double(grib_expression*,grib_handle*,double*);
+static string evaluate_string(grib_expression*,grib_handle*,char*,size_t*,int*);
 
-typedef struct grib_expression_is_integer
-{
-    grib_expression base;
+typedef struct grib_expression_is_integer{
+  grib_expression base;
     /* Members defined in is_integer */
-    char* name;
+    char *name;
     size_t start;
     size_t length;
 } grib_expression_is_integer;
 
 
 static grib_expression_class _grib_expression_class_is_integer = {
-    0,                                  /* super                     */
-    "is_integer",                       /* name                      */
-    sizeof(grib_expression_is_integer), /* size of instance          */
-    0,                                  /* inited */
-    &init_class,                        /* init_class */
-    0,                                  /* constructor               */
-    &destroy,                           /* destructor                */
-    &print,
-    &add_dependency,
+    0,                    /* super                     */
+    "is_integer",                    /* name                      */
+    sizeof(grib_expression_is_integer),/* size of instance          */
+    0,                           /* inited */
+    &init_class,                 /* init_class */
+    0,                     /* constructor               */
+    &destroy,                  /* destructor                */
+    &print,                 
+    &add_dependency,       
 
-    &native_type,
-    &get_name,
+	&native_type,
+	&get_name,
 
-    &evaluate_long,
-    &evaluate_double,
-    &evaluate_string,
+	&evaluate_long,
+	&evaluate_double,
+	&evaluate_string,
 };
 
 grib_expression_class* grib_expression_class_is_integer = &_grib_expression_class_is_integer;
