@@ -828,7 +828,7 @@ int grib_index_write(grib_index* index, const char* filename)
     int err = 0;
     FILE* fh;
     grib_file* files;
-    char* identifier = NULL;
+    const char* identifier = NULL;
 
     fh = fopen(filename, "w");
     if (!fh) {
@@ -993,7 +993,7 @@ int grib_index_search_same(grib_index* index, grib_handle* h)
     grib_index_key* keys;
     long lval   = 0;
     double dval = 0.0;
-    grib_context* c;
+    grib_context* c = NULL;
 
     if (!index)
         return GRIB_NULL_INDEX;
@@ -1065,6 +1065,8 @@ static grib_handle* new_message_from_file(int message_type, grib_context* c, FIL
     return NULL;
 }
 
+#define MAX_NUM_KEYS 40
+
 int _codes_index_add_file(grib_index* index, const char* filename, int message_type)
 {
     double dval;
@@ -1126,7 +1128,24 @@ int _codes_index_add_file(grib_index* index, const char* filename, int message_t
         field_tree          = index->fields;
         index_key->value[0] = 0;
         message_count++;
-        
+
+        {
+            char* envsetkeys = getenv("ECCODES_INDEX_SET_KEYS");
+            if (envsetkeys) {
+                grib_values set_values[MAX_NUM_KEYS];
+                int set_values_count = MAX_NUM_KEYS;
+                int error = parse_keyval_string(NULL, envsetkeys, 1, GRIB_TYPE_UNDEFINED,
+                        set_values, &set_values_count);
+                if (!error && set_values_count != 0) {
+                    err = grib_set_values(h, set_values, set_values_count);
+                    if (err) {
+                        grib_context_log(c, GRIB_LOG_ERROR,"codes_index_add_file: unable to set %s\n", envsetkeys);
+                        return err;
+                    }
+                }
+            }
+        }
+
         if (index->product_kind == PRODUCT_BUFR && index->unpack_bufr) {
             err = grib_set_long(h, "unpack", 1);
             if (err) {
@@ -1168,7 +1187,8 @@ int _codes_index_add_file(grib_index* index, const char* filename, int message_t
                     return err;
             }
             if (err && err != GRIB_NOT_FOUND) {
-                grib_context_log(c, GRIB_LOG_ERROR, "unable to create index. \"%s\": %s", index_key->name, grib_get_error_message(err));
+                grib_context_log(c, GRIB_LOG_ERROR, "unable to create index. key=\"%s\" (message #%lu): %s",
+                                 index_key->name, message_count, grib_get_error_message(err));
                 return err;
             }
 
@@ -1883,8 +1903,7 @@ grib_handle* codes_new_from_index(grib_index* index, int message_type, int* err)
                                                                       sizeof(grib_field_list));
         if (!index->fieldset) {
             grib_context_log(index->context, GRIB_LOG_ERROR,
-                             "unable to allocate %d bytes",
-                             sizeof(grib_field_list));
+                             "unable to allocate %lu bytes", sizeof(grib_field_list));
             return NULL;
         }
         index->current = index->fieldset;
