@@ -36,15 +36,14 @@ or edit "nearest.class" and rerun ./make_class.pl
 */
 
 
-static void init_class(grib_nearest_class*);
+static void init_class              (grib_nearest_class*);
 
-static int init(grib_nearest* nearest, grib_handle* h, grib_arguments* args);
-static int find(grib_nearest* nearest, grib_handle* h, double inlat, double inlon, unsigned long flags, double* outlats, double* outlons, double* values, double* distances, int* indexes, size_t* len);
-static int destroy(grib_nearest* nearest);
+static int init               (grib_nearest* nearest,grib_handle* h,grib_arguments* args);
+static int find(grib_nearest* nearest, grib_handle* h,double inlat, double inlon, unsigned long flags, double* outlats,double* outlons, double *values,double *distances, int *indexes,size_t *len);
+static int destroy            (grib_nearest* nearest);
 
-typedef struct grib_nearest_sh
-{
-    grib_nearest nearest;
+typedef struct grib_nearest_sh{
+  grib_nearest nearest;
     /* Members defined in gen */
     const char* values_key;
     const char* radius;
@@ -58,14 +57,14 @@ typedef struct grib_nearest_sh
 extern grib_nearest_class* grib_nearest_class_gen;
 
 static grib_nearest_class _grib_nearest_class_sh = {
-    &grib_nearest_class_gen, /* super                     */
-    "sh",                    /* name                      */
-    sizeof(grib_nearest_sh), /* size of instance          */
-    0,                       /* inited */
-    &init_class,             /* init_class */
-    &init,                   /* constructor               */
-    &destroy,                /* destructor                */
-    &find,                   /* find nearest              */
+    &grib_nearest_class_gen,                         /* super */
+    "sh",                         /* name */
+    sizeof(grib_nearest_sh),      /* size of instance */
+    0,                              /* inited */
+    &init_class,                    /* init_class */
+    &init,                          /* constructor */
+    &destroy,                       /* destructor */
+    &find,                          /* find nearest */
 };
 
 grib_nearest_class* grib_nearest_class_sh = &_grib_nearest_class_sh;
