@@ -27,7 +27,7 @@ int strcmp_nocase(const char* s1, const char* s2)
 }
 
 /* Strip whitespace from the end of a string */
-void rtrim(char* s)
+void string_rtrim(char* s)
 {
     size_t len = 0;
     if (!s)
@@ -38,7 +38,7 @@ void rtrim(char* s)
     s[len] = '\0';
 }
 
-void lrtrim(char** x, int do_left, int do_right)
+void string_lrtrim(char** x, int do_left, int do_right)
 {
     DebugAssert(do_left || do_right);
     if (do_left) {
@@ -148,20 +148,20 @@ int string_to_long(const char* input, long* output)
     return GRIB_SUCCESS;
 }
 
-/* Return 1 if str1 ends with str2, 0 otherwise */
-int string_ends_with(const char* str1, const char* str2)
+/* Return 1 if 's' ends with 'suffix', 0 otherwise */
+int string_ends_with(const char* s, const char* suffix)
 {
-    const size_t len1 = strlen(str1);
-    const size_t len2 = strlen(str2);
+    const size_t len1 = strlen(s);
+    const size_t len2 = strlen(suffix);
     if (len2 > len1)
         return 0;
 
-    if (strcmp(&str1[len1 - len2], str2) == 0)
+    if (strcmp(&s[len1 - len2], suffix) == 0)
         return 1;
     return 0;
 }
 
-int count_char_in_string(const char* str, char c)
+int string_count_char(const char* str, char c)
 {
     int i = 0, count = 0;
     DebugAssert(str);
@@ -170,3 +170,68 @@ int count_char_in_string(const char* str, char c)
     }
     return count;
 }
+
+const char* codes_get_product_name(ProductKind product)
+{
+    switch (product) {
+        case PRODUCT_GRIB:
+            return "GRIB";
+        case PRODUCT_BUFR:
+            return "BUFR";
+        case PRODUCT_METAR:
+            return "METAR";
+        case PRODUCT_GTS:
+            return "GTS";
+        case PRODUCT_TAF:
+            return "TAF";
+        case PRODUCT_ANY:
+            return "ANY";
+    }
+    return "unknown";
+}
+
+const char* grib_get_type_name(int type)
+{
+    switch (type) {
+        case GRIB_TYPE_LONG:
+            return "long";
+        case GRIB_TYPE_STRING:
+            return "string";
+        case GRIB_TYPE_BYTES:
+            return "bytes";
+        case GRIB_TYPE_DOUBLE:
+            return "double";
+        case GRIB_TYPE_LABEL:
+            return "label";
+        case GRIB_TYPE_SECTION:
+            return "section";
+    }
+    return "unknown";
+}
+
+/* Replace all occurrences of character in string.
+*  Returns pointer to the NUL byte at the end of 's'
+*/
+char *string_replace_char(char *s, char oldc, char newc)
+{
+    for (; *s; ++s)
+        if (*s == oldc)
+            *s = newc;
+    return s;
+}
+
+/* Remove all instances of character 'c' from 'str' */
+void string_remove_char(char * str, char c)
+{
+    size_t i, j;
+    size_t len = strlen(str);
+    for(i=0; i<len; i++) {
+        if(str[i] == c) {
+            for(j=i; j<len; j++) {
+                str[j] = str[j+1];
+            }
+            len--;
+            i--;
+        }
+    }
+}
