@@ -7,17 +7,17 @@
 # In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
-. ./include.sh
-set -u
-REDIRECT=/dev/null
+. ./include.ctest.sh
 
-label="grib2_version"
+
+label="grib2_version_test"
 if [ ! -d "$ECCODES_DEFINITION_PATH" ]; then
     echo "Test $0 disabled. No definitions directory"
     exit 0
 fi
 
 temp=temp.$label.grib2
+sample1=$ECCODES_SAMPLES_PATH/GRIB1.tmpl
 sample2=$ECCODES_SAMPLES_PATH/GRIB2.tmpl
 tables_dir="$ECCODES_DEFINITION_PATH/grib2/tables"
 
@@ -31,4 +31,23 @@ if [ "$latest" != "$highest_num" ]; then
     exit 1
 fi
 
+
+# Check table 1.0
+# Check it has the latest with description matching "Version implemented on DD MM YYYY"
+tempText=temp.$label.txt
+${tools_dir}/grib_set -s tablesVersion=$latest $sample2 $temp
+${tools_dir}/grib_dump -O -p tablesVersion $temp > $tempText
+grep -q "Version implemented on" $tempText
+rm -f $tempText
+
+
+# Also grib1 to grib2 conversion should set the official version, not the highest
+${tools_dir}/grib_set -s edition=2 $sample1 $temp
+tablesVersion=`${tools_dir}/grib_get -p tablesVersion $temp`
+latestOfficial=`${tools_dir}/grib_get -p tablesVersionLatestOfficial $temp`
+if [ "$tablesVersion" != "$latestOfficial" ]; then
+    echo "After conversion to GRIB2, tablesVersion=$tablesVersion. Should be $latestOfficial"
+    exit 1
+fi
+
 rm -f $temp
