@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2019 ECMWF.
+ * (C) Copyright 2005- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -17,7 +17,7 @@
 #define BUFF_SIZE 10000000
 
 #ifdef HAVE_LIBEMOS
-#if GRIB_TIMER
+#if ECCODES_TIMER
 #define TEST_OK
 #endif
 #endif
