@@ -8,9 +8,10 @@
  * virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
  */
 
-#include <assert.h>
 #include "grib_api_internal.h"
 
+#define STR_EQUAL(s1, s2) (strcmp((s1), (s2)) == 0)
+
 int assertion_caught = 0;
 
 typedef enum
@@ -21,7 +22,7 @@ typedef enum
 
 static void compare_doubles(const double d1, const double d2, const double epsilon)
 {
-    assert(fabs(d1 - d2) < epsilon);
+    Assert(fabs(d1 - d2) < epsilon);
 }
 
 static void check_float_representation(const double val, const double expected, const FloatRep rep)
@@ -29,9 +30,9 @@ static void check_float_representation(const double val, const double expected,
     double out             = 0;
     const double tolerance = 1e-9;
     if (rep == IBM_FLOAT)
-        assert(grib_nearest_smaller_ibm_float(val, &out) == GRIB_SUCCESS);
+        Assert(grib_nearest_smaller_ibm_float(val, &out) == GRIB_SUCCESS);
     else
-        assert(grib_nearest_smaller_ieee_float(val, &out) == GRIB_SUCCESS);
+        Assert(grib_nearest_smaller_ieee_float(val, &out) == GRIB_SUCCESS);
 
     /*printf("%s: d1=%10.20f, out=%10.20f\n", (rep==IBM_FLOAT)?"ibm":"ieee", val, out);*/
 
@@ -45,6 +46,15 @@ static void test_get_git_sha1()
     printf("Testing: test_get_git_sha1... %s\n", sha1);
 }
 
+static void test_get_build_date()
+{
+    const char* bdate = codes_get_build_date();
+    Assert(bdate != NULL);
+    /* Should be of the format YYYY.MM.DD or empty (not implemented) */
+    Assert( strlen(bdate) == 0 || isdigit(bdate[0]) );
+    printf("Testing: test_get_build_date... %s\n", bdate);
+}
+
 static void test_grib_nearest_smaller_ibmfloat()
 {
     printf("Testing: test_grib_nearest_smaller_ibmfloat...\n");
@@ -1389,9 +1399,9 @@ static void test_string_splitting()
     printf("Testing: test_string_splitting...\n");
 
     list           = string_split(input, "|");
-    if (!list) { assert(!"List is NULL"); return; }
+    if (!list) { Assert(!"List is NULL"); return; }
     for (i = 0; list[i] != NULL; ++i) {} /* count how many tokens */
-    assert(i == 4);
+    Assert(i == 4);
     if (!list[0] || !STR_EQ(list[0], "Born")) Assert(0);
     if (!list[1] || !STR_EQ(list[1], "To"))   Assert(0);
     if (!list[2] || !STR_EQ(list[2], "Be"))   Assert(0);
@@ -1402,22 +1412,22 @@ static void test_string_splitting()
 
     strcpy(input, "12345|a gap|");
     list = string_split(input, "|");
-    if (!list) { assert(0); return; }
+    if (!list) { Assert(0); return; }
     for (i = 0; list[i] != NULL; ++i) {} /* count how many tokens */
-    assert(i == 2);
+    Assert(i == 2);
     if (!list[0] || !STR_EQ(list[0], "12345")) Assert(0);
     if (!list[1] || !STR_EQ(list[1], "a gap")) Assert(0);
-    assert(list[2] == NULL);
+    Assert(list[2] == NULL);
     for (i = 0; list[i] != NULL; ++i) free(list[i]);
     free(list);
 
     strcpy(input, "Steppenwolf");
     list = string_split(input, ",");
-    if (!list) { assert(0); return; }
+    if (!list) { Assert(0); return; }
     for (i = 0; list[i] != NULL; ++i) {} /* count how many tokens */
-    assert(i == 1);
+    Assert(i == 1);
     if (!list[0] || !STR_EQ(list[0], "Steppenwolf")) Assert(0);
-    assert(list[1] == NULL);
+    Assert(list[1] == NULL);
     for (i = 0; list[i] != NULL; ++i) free(list[i]);
     free(list);
 
@@ -1438,7 +1448,7 @@ static void test_assertion_catching()
     char empty[] = "";
     char** list  = 0;
     int i        = 0;
-    assert(assertion_caught == 0);
+    Assert(assertion_caught == 0);
     codes_set_codes_assertion_failed_proc(&my_assertion_proc);
     
     printf("Testing: test_assertion_catching...\n");
@@ -1446,7 +1456,7 @@ static void test_assertion_catching()
     /* Do something illegal */
     list = string_split(empty, " ");
 
-    assert(assertion_caught == 1);
+    Assert(assertion_caught == 1);
 
     /* Restore everything */
     codes_set_codes_assertion_failed_proc(NULL);
@@ -1461,7 +1471,8 @@ static void test_concept_condition_strings()
 {
     int err           = 0;
     char result[1024] = {0,};
-    grib_handle* h = grib_handle_new_from_samples(0, "GRIB2");
+    grib_context* context = NULL;
+    grib_handle* h = grib_handle_new_from_samples(context, "GRIB2");
 
     printf("Testing: test_concept_condition_strings...\n");
 
@@ -1497,20 +1508,49 @@ static void test_trimming()
     char* pD = d;
     char* pE = e;
 
-    lrtrim(&pA, 0, 1); /*right only*/
-    assert( strcmp(pA, " Standing")==0 );
+    printf("Testing: test_trimming...\n");
 
-    lrtrim(&pB, 1, 0); /*left only*/
-    assert( strcmp(pB, "Weeping ")==0 );
+    string_lrtrim(&pA, 0, 1); /*right only*/
+    Assert( strcmp(pA, " Standing")==0 );
 
-    lrtrim(&pC, 1, 1); /*both ends*/
-    assert( strcmp(pC, "Silhouette")==0 );
+    string_lrtrim(&pB, 1, 0); /*left only*/
+    Assert( strcmp(pB, "Weeping ")==0 );
 
-    lrtrim(&pD, 1, 1); /*make sure other spaces are not removed*/
-    assert( strcmp(pD, "The Forest Of October")==0 );
+    string_lrtrim(&pC, 1, 1); /*both ends*/
+    Assert( strcmp(pC, "Silhouette")==0 );
 
-    lrtrim(&pE, 1, 1); /* Other chars */
-    assert( strcmp(pE, "Apostle In Triumph")==0 );
+    string_lrtrim(&pD, 1, 1); /*make sure other spaces are not removed*/
+    Assert( strcmp(pD, "The Forest Of October")==0 );
+
+    string_lrtrim(&pE, 1, 1); /* Other chars */
+    Assert( strcmp(pE, "Apostle In Triumph")==0 );
+}
+
+static void test_string_ends_with()
+{
+    printf("Testing: test_string_ends_with...\n");
+    Assert( string_ends_with("GRIB2.tmpl", "tmpl") == 1 );
+    Assert( string_ends_with("GRIB2.tmpl", ".tmpl") == 1 );
+    Assert( string_ends_with("", "") == 1 );
+    Assert( string_ends_with(".", ".") == 1 );
+    Assert( string_ends_with("Bam", "") == 1 );
+
+    Assert( string_ends_with("GRIB2.tmpl", "tmp") == 0 );
+    Assert( string_ends_with("GRIB2.tmpl", "tmpl0") == 0 );
+    Assert( string_ends_with("GRIB2.tmpl", "1.tmpl") == 0 );
+    Assert( string_ends_with("GRIB2.tmpl", " ") == 0 );
+}
+
+static void test_gribex_mode()
+{
+    grib_context* c = grib_context_get_default();
+    printf("Testing: test_gribex_mode...\n");
+
+    Assert( grib_get_gribex_mode(c) == 0 ); /* default is OFF */
+    grib_gribex_mode_on(c);
+    Assert( grib_get_gribex_mode(c) == 1 );
+    grib_gribex_mode_off(c);
+    Assert( grib_get_gribex_mode(c) == 0 );
 }
 
 int main(int argc, char** argv)
@@ -1518,8 +1558,11 @@ int main(int argc, char** argv)
     /*printf("Doing unit tests. ecCodes version = %ld\n", grib_get_api_version());*/
     
     test_trimming();
+    test_string_ends_with();
 
     test_get_git_sha1();
+    test_get_build_date();
+    test_gribex_mode();
 
     test_concept_condition_strings();
 
