@@ -100,11 +100,11 @@ static int onlyListed          = 1;
 static int headerMode          = 0;
 static int morein1             = 0;
 static int morein2             = 0;
-static int listFromCommandLine;
-static int verbose          = 0;
-static int tolerance_factor = 1;
-static int write_error      = 0;
-static int write_count      = 0;
+static int listFromCommandLine = 0;
+static int verbose             = 0;
+static double tolerance_factor = 1;
+static int write_error         = 0;
+static int write_count         = 0;
 
 static grib_handle* global_handle = NULL;
 static int counter                = 0;
@@ -306,7 +306,7 @@ int grib_tool_init(grib_runtime_options* options)
     exit_if_input_is_directory(tool_name, options->infile_extra->name);
 
     if (grib_options_on("r")) {
-        char* filename[1];
+        const char* filename[1];
         filename[0]      = options->infile_extra->name;
         options->random  = 1;
         options->orderby = strdup(orderby);
