@@ -45,9 +45,9 @@ grib_option grib_options[] = {
 const char* tool_description =
     "List content of GRIB files printing values of "
     "some keys.\n\tIt does not fail when a key is not found.";
-const char* tool_name  = "grib_ls";
-const char* tool_usage = "[options] grib_file grib_file ...";
-static char* new_handle     = "";
+const char* tool_name   = "grib_ls";
+const char* tool_usage  = "[options] grib_file grib_file ...";
+static const char* new_handle = "";
 
 int grib_options_count = sizeof(grib_options) / sizeof(grib_option);
 static double lat      = 0;
@@ -100,7 +100,7 @@ int grib_tool_init(grib_runtime_options* options)
     if (options->latlon) {
         lat = strtod(options->latlon, &theEnd);
         if (*theEnd != ',') {
-            fprintf(stderr, "Error %s: wrong latitude value. Please use 'latitude,longitude'\n",tool_name);
+            fprintf(stderr, "Error %s: wrong latitude value. Please use 'latitude,longitude'\n", tool_name);
             exit(1);
         }
         lon = strtod(++theEnd, &end1);
@@ -219,7 +219,7 @@ static void print_key_values(grib_runtime_options* options, grib_handle* h)
 {
     int i;
     int ret       = 0;
-    char* s       = "\"keys\" : {";
+    const char* s = "\"keys\" : {";
     double dvalue = 0;
     long lvalue   = 0;
     char value[MAX_STRING_LEN];
@@ -285,11 +285,17 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
         if (!nearest)
             nearest = grib_nearest_new(h, &err);
         if (err == GRIB_NOT_IMPLEMENTED) {
-            char grid_type[100];
-            size_t grid_type_len = 100;
-            int err1             = grib_get_string(h, "gridType", grid_type, &grid_type_len);
-            if (err1 == GRIB_SUCCESS) {
-                fprintf(stderr, "Nearest neighbour functionality is not supported for grid type: %s\n", grid_type);
+            char grid_type[100], grid_desc[200];
+            size_t g_len = sizeof(grid_type);
+            int err1 = 0, err2 = 0;
+            err1 = grib_get_string(h, "gridType", grid_type, &g_len);
+            g_len = sizeof(grid_desc);
+            err2 = grib_get_string(h, "gridDefinitionDescription", grid_desc, &g_len);
+            if (!err1 && !err2) {
+                fprintf(stderr, "Nearest neighbour functionality is not supported for grid type: %s (%s)\n",
+                        grid_type, grid_desc);
+            } else {
+                fprintf(stderr, "Nearest neighbour functionality is not supported for this grid type\n");
             }
         }
         GRIB_CHECK_NOLINE(err, 0);
@@ -316,21 +322,31 @@ int grib_tool_new_handle_action(grib_runtime_options* options, grib_handle* h)
         }
 
         if (json_latlon) {
-            char* s             = "\n[\n";
+            int istart = 0;
+            int iend   = LATLON_SIZE;
+            const char* s       = "\n[\n";
             double missingValue = 9999;
             char value[MAX_STRING_LEN];
             size_t len = MAX_STRING_LEN;
             printf("%s", new_handle);
             printf("{\n");
             print_key_values(options, h);
-            printf("\n, \"selected\" : %d", options->latlon_idx);
+            if (options->latlon_mode == 4) {
+                printf("\n, \"selected\" : %d", options->latlon_idx);
+            } else {
+                printf("\n");
+            }
             printf(", \"method\" : ");
             if (options->latlon_mask)
                 printf("\"nearest_land\"");
             else
                 printf("\"nearest\"");
             printf("\n, \"neighbours\" : ");
-            for (i = 0; i < LATLON_SIZE; i++) {
+            if (options->latlon_mode == 1) {
+                istart = options->latlon_idx;
+                iend = istart + 1;
+            }
+            for (i = istart; i < iend; i++) {
                 printf("%s", s);
                 len = MAX_STRING_LEN;
                 printf(
@@ -400,10 +416,10 @@ int grib_tool_finalise_action(grib_runtime_options* options)
         printf("Input Point: latitude=%.2f  longitude=%.2f\n", lat, lon);
         if (options->latlon_idx >= 0 && options->latlon_idx < LATLON_SIZE) {
             printf("Grid Point chosen #%d index=%d latitude=%.2f longitude=%.2f distance=%.2f (Km)\n",
-                options->latlon_idx + 1, (int)options->indexes[options->latlon_idx],
-                options->lats[options->latlon_idx],
-                options->lons[options->latlon_idx],
-                options->distances[options->latlon_idx]);
+                   options->latlon_idx + 1, (int)options->indexes[options->latlon_idx],
+                   options->lats[options->latlon_idx],
+                   options->lons[options->latlon_idx],
+                   options->distances[options->latlon_idx]);
         }
         if (options->latlon_mask) {
             printf("Mask values:\n");
